#ifndef TRANSLATE_H

#define TRANSLATE_H

// Build a random ASCII translation table between one alphabet and another.

#include "rand.h"

class Translate
{
public:
  Translate(int key) // build ASCII translation table.
  {
    RandPool pool(255,key); // random number pool.
    for (int i=0; i<255; i++)
    {
      bool shuffled;
      unsigned char v = pool.Get(shuffled)+1;
      mTableIn[i+1]   = v;
      mTableOut[v]    = i+1;
    }
    mTableIn[0]  = 0; // zero always translates to zero!
    mTableOut[0] = 0;
  };

  unsigned char TranslateIn(unsigned char c) const
  {
	  return mTableIn[c];
  };

  unsigned char TranslateOut(unsigned char c) const
  {
	  return mTableOut[c];
  };

  int TranslateIn(unsigned char *foo)
  {
    // translate asciiz string into or out of translation table
    int len = 0;
    while ( *foo )
    {
  	  unsigned char v = *foo;
	    v = TranslateIn(v);
	    *foo++ = v;
      len++;
    }
    return len; // returns length of string translated.
  };

  int TranslateOut(unsigned char *foo)
  {
    // translate asciiz string into or out of translation table
    int len = 0;
    while ( *foo )
    {
  	  unsigned char v = *foo;
	    v = TranslateOut(v);
	    *foo++ = v;
      len++;
    }
    return len; // returns length of string translated.
  };

private:
  unsigned char mTableIn[256];
  unsigned char mTableOut[256];
};

#endif
